/*
NAME
	errors.h

SYNOPSYS
	void debug (register char const *const fmt, ...);
	void info (register char const *const fmt, ...);
	void notice (register char const *const fmt, ...);
	void warn (register char const *const fmt, ...);
	void error (register char const *const fmt, ...);
	void fatal (register char const *const fmt, ...);

	void errors_fini (void);
	int errors_init (register char const *const pn,
	                 register char const *const facility_name,
	                 register char const *const priority_name);

DESCRIPTION
	Send fatal, error, warning, notice, and info, messages to the
	proper destination, i.e. either to the syslog or to stderr.

AUTHOR
	Ronald F. Guilmette <rfg@monkeys.com>

COPYRIGHT
	Copyright (c) 2002 Ronald F. Guilmette; All rights reserved.

	The author and copyright holder of this software specifically and
	explicitly DISALLOWS any and all uses of this software, or any
	compiled and/or derivative version thereof for any and all commercial
	purposes without the express written permission of the copyright
	holder to the contrary.

	Requests for permission to use this software, or any compiled and/or
	derivative work thereof, either in a commercial context or for com-
	mercial gain or for any commercial purpose should be e-mailed to the
	copyright holder at the e-mail address given above.

DISCLAIMER
	THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS''
	AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
	TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
	PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR
	OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
	SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
	LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
	USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
	AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
	OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
	OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
	SUCH DAMAGE.
*/

extern void
debug (register char const *const fmt, ...)
       __attribute__ ((format (printf, 1, 2)));

extern void
info (register char const *const fmt, ...)
       __attribute__ ((format (printf, 1, 2)));

extern void
notice (register char const *const fmt, ...)
       __attribute__ ((format (printf, 1, 2)));

extern void
warn (register char const *const fmt, ...)
       __attribute__ ((format (printf, 1, 2)));

extern void
error (register char const *const fmt, ...)
       __attribute__ ((format (printf, 1, 2)));

extern void
fatal (register char const *const fmt, ...)
       __attribute__ ((format (printf, 1, 2)))
       __attribute__ ((noreturn));

extern void
errors_fini (void);

extern int
errors_init (register char const *const pn,
	     register char const *const facility_name,
	     register char const *const priority_name);
