/*
NAME
	utils.h

SYNOPSYS
	void *
	xmalloc (register unsigned long const size);

	char *
	xstrdup (register char const *const s);

	void
	xfree (register void *const ptr);
	
	Bool
	all_digits (register char const *const s);
	
	int
	my_inet_aton (register char const *const host_name,
		      register struct in_addr *const addr);

	size_t
	xfgets (register char *const s,
		register size_t const size,
		register FILE *const ifile);
	
	size_t
	t_xfgets (register char *const buf,
	          register size_t const size,
	          register FILE *const xfile,
	          register unsigned int const timeout);
	
	size_t
	t_fread (register void *const buf,
	         register size_t const size,
	         register size_t const count,
	         register FILE *const xfile,
	         register unsigned int const timeout);
	
	size_t
	t_fwrite (register void const *const buf,
	          register size_t const size,
	          register size_t const count,
	          register FILE *const xfile,
	          register unsigned int const timeout);
	
	int
	t_connect (register int const s,
	           register struct sockaddr *const sp,
	           register socklen_t const size,
	           register unsigned int const timeout);
	
	void
	showline (register char *const line,
	          register size_t const len);
	
	int
	port_for (register char const *const service_name);
	
	const char *
	current_userid (void);
	
	typedef void (handler_func) (register int const signo);
	
	void
	set_signal_handler (register int const signo,
			    handler_func *const handler);

DESCRIPTION
	tbd

AUTHOR
	Ronald F. Guilmette <rfg@monkeys.com>

COPYRIGHT
	Copyright (c) 2002 Ronald F. Guilmette; All rights reserved.

	The author and copyright holder of this software specifically and
	explicitly DISALLOWS any and all uses of this software, or any
	compiled and/or derivative version thereof for any and all commercial
	purposes without the express written permission of the copyright
	holder to the contrary.

	Requests for permission to use this software, or any compiled and/or
	derivative work thereof, either in a commercial context or for com-
	mercial gain or for any commercial purpose should be e-mailed to the
	copyright holder at the e-mail address given above.

DISCLAIMER
	THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS''
	AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
	TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
	PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR
	OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
	SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
	LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
	USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
	AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
	OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
	OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
	SUCH DAMAGE.
*/

struct in_addr;

extern void *
xmalloc (register unsigned long const size);

extern char *
xstrdup (register char const *const s);

extern void
xfree (register void *const ptr);

extern Bool
all_digits (register char const *const s);

extern int
my_inet_aton (register char const *const host_name,
	      register struct in_addr *const addr);

/* Like fgets, except this returns a size_t result, which will be 0 on error
   or EOF, or if `size' bytes have been read without encountering a newline.
   Otherwise the value returned is the number of bytes stored, including the
   terminating newline.

   Unlike fgets, this routine discards any nul bytes encountered on input.

   Unlike fgets, this routine DOES NOT store a nul byte after the input
   bytes stored in the string `s'.  */

extern size_t
xfgets (register char *const s,
	register size_t const size,
	register FILE *const ifile);

extern size_t
t_xfgets (register char *const buf,
          register size_t const size,
          register FILE *const xfile,
          register unsigned int const timeout);

extern size_t
t_fread (register void *const buf,
         register size_t const size,
         register size_t const count,
         register FILE *const xfile,
         register unsigned int const timeout);

extern size_t
t_fwrite (register void const *const buf,
          register size_t const size,
          register size_t const count,
          register FILE *const xfile,
          register unsigned int const timeout);

extern int
t_connect (register int const s,
           register struct sockaddr *const sp,
           register socklen_t const size,
           register unsigned int const timeout);

extern void
showline (register char *const line,
          register size_t const len);

extern int
port_for (register char const *const service_name);

extern const char *
current_userid (void);

typedef void (handler_func) (register int const signo);

extern void
set_signal_handler (register int const signo, handler_func *const handler);
